@@ -1,8 +1,3 @@
-"""
-Source processing classes
-=========================
-"""
-
 import datetime
 import glob
 import hashlib
@@ -1053,8 +1048,7 @@ class EPSSDownloads(CSVFileHandler):
         if epss is not None:
             self.queue.put(
                 DatabaseAction(
-                    action=DatabaseAction.actions.UpdateOne,
-                    doc=epss,
+                    action=DatabaseAction.actions.UpdateOne, doc=epss, upsert=False
                 )
             )
 
